@@ -1,5 +1,6 @@
 from django.contrib.auth.models import AnonymousUser
 from django.test import TestCase
+from incuna_test_utils.testcases.request import RequestTestCase as RequestTestCaseBase
 from rest_framework.test import APIRequestFactory, force_authenticate
 
 from .factories import UserFactory
@@ -22,3 +23,7 @@ class APIRequestTestCase(TestCase):
         if 'data' in kwargs:
             request.DATA = kwargs['data']
         return request
+
+
+class RequestTestCase(RequestTestCaseBase):
+    user_factory = UserFactory
